@@ -10,6 +10,18 @@ class NewLimitOrderMessage(BaseEventMessage):
     price_delta: float
     selling: bool
 
+class NewArbitrageSpotTradeMessage(BaseEventMessage):
+    generator_order_id: str
+    generator_order_status: str
+    generator_order_type: str
+    origin_exchange: str
+    target_exchange: str
+    origin_market: str
+    target_market: str
+    amount: float
+    usd_observed: float
+
+
 
 class NewSpotOrderMessage(BaseEventMessage):
     exchange: str
